#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

setup(
    name='herbatis',
    version='0.0.6',
    author='Mr.Zhang',
    author_email='zhang.pengbird@gmail.com',
    url='https://zhuanlan.zhihu.com/p/26159930',
    description=u'A mybatis of python',
    packages=['test'],
    install_requires=[],
    entry_points={
        'console_scripts': [
        ]
    }
)